==> owncloud-10.0.3.tgz: owncloud/apps/files_external/l10n/th_TH.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "การเรียกร้องขอโทเคนล้มเหลว โปรดตรวจสอบคีย์และรหัสลับให้ถูกต้อง",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "การเรียกร้องขอโทเคนล้มเหลว โปรดตรวจสอบคีย์และรหัสลับของแอพฯ ให้ถูกต้อง",
    "Please provide a valid app key and secret." : "โปรดระบุคีย์และรหัสลับของแอพฯ ให้ถูกต้อง",
    "Step 1 failed. Exception: %s" : "ขั้นตอนที่ 1 ล้มเหลว ข้อยกเว้น: %s",
    "Step 2 failed. Exception: %s" : "ขั้นตอนที่ 2 ล้มเหลว ข้อยกเว้น: %s",
    "External storage" : "จัดเก็บข้อมูลภายนอก",
    "Dropbox App Configuration" : "ตั้งค่าแอพฯ Dropbox",
    "Google Drive App Configuration" : "ตั้งค่าแอพฯ Google Drive",
    "Personal" : "ส่วนตัว",
    "System" : "ระบบ",
    "Grant access" : "อนุญาตให้เข้าถึงได้",
    "Error configuring OAuth1" : "ข้อผิดพลาดในการกำหนดค่า OAuth1",
    "Error configuring OAuth2" : "ข้อผิดพลาดในการกำหนดค่า OAuth2",
    "Generate keys" : "สร้างคีย์",
    "Error generating key pair" : "ข้อผิดพลาดในการสร้างคีย์แบบเป็นคู่",
    "All users. Type to select user or group." : "ผู้ใช้ทุกคน พิมพ์เพื่อเลือกผู้ใช้หรือกลุ่ม",
    "(group)" : "(กลุ่ม)",
    "Compatibility with Mac NFD encoding (slow)" : "ความเข้ากันได้กับการเข้ารหัส Mac NFS (ช้า)",
    "Admin defined" : "ถูกกำหนดโดยผู้ดูแลระบบ",
    "Saved" : "บันทึกแล้ว",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "หากปิดการใช้งานการจัดเก็บข้อมูลภายนอก ข้อมูลของผู้ใช้ทั้งหมดจะถูกยกเลิกการต่อเชื่อม คุณแน่ใจ?",
    "Disable external storage" : "ปิดการใช้งานพื้นที่จัดเก็บข้อมูลภายนอก",
    "Empty response from the server" : "ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
    "Couldn't access. Please logout and login to activate this mount point" : "ไม่สามารถเข้าถึง กรุณออกจากระบบและาเข้าสู่ระบบใหม่เพื่อเปิดใช้งานจุดเชื่อมต่อนี้",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "ไม่สามารถรับข้อมูลจากเซิร์ฟเวอร์ ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "ไม่สามารถรับรายชื่อของจุดเชื่อมต่อภายนอก: {type}",
    "There was an error with message: " : "มีข้อความแสดงข้อผิดพลาด",
    "External mount error" : "การติดจากตั้งภายนอกเกิดข้อผิดพลาด",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "ไม่สามารถรับรายชื่อไดรฟ์เครือข่ายของวินโดว์ส จุดที่ติดตั้ง: ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "การกำหนดค่าบางส่วนของจุดเชื่อมต่อภายนอกไม่ถูกเชื่อมต่อ กรุณาคลิกที่ตรงสีแดงสำหรับข้อมูลเพิ่มเติม",
    "Please enter the credentials for the {mount} mount" : "กรุณากรอกข้อมูลประจำตัวสำหรับ {mount} ",
    "Username" : "ชื่อผู้ใช้งาน",
    "Password" : "รหัสผ่าน",
    "Credentials saved" : "ข้อมูลประจำตัวได้ถูกบันทึก",
    "Credentials saving failed" : "บันทึกข้อมูลประจำตัวล้มเหลว",
    "Credentials required" : "จำเป็นต้องระบบข้อมูลประจำตัว",
    "Save" : "บันทึก",
    "Storage with id \"%i\" not found" : "ไม่พบจัดการเก็บข้อมูลของ ID \"%i\"",
    "Invalid backend or authentication mechanism class" : "แบ็กเอนด์ไม่ถูกต้องหรือระดับการรับรองความถูกต้องไม่เพียงพอ",
    "Invalid mount point" : "จุดเชื่อมต่อที่ไม่ถูกต้อง",
    "Objectstore forbidden" : "เก็บวัตถุต้องห้าม",
    "Invalid storage backend \"%s\"" : "การจัดเก็บข้อมูลแบ็กเอนด์ไม่ถูกต้อง \"%s\"",
    "Not permitted to use backend \"%s\"" : "ไม่อนุญาตให้ใช้แบ็กเอนด์ \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "ไม่อนุญาตให้ตรวจสอบการรับรองความถูกต้อง \"%s\"",
    "Unsatisfied backend parameters" : "พารามิเตอร์แบ็กเอนด์ไม่ได้รับอนุญาต",
    "Unsatisfied authentication mechanism parameters" : "การรับรองความถูกต้องไม่เพียงพอ",
    "Insufficient data: %s" : "ข้อมูลไม่เพียงพอ: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "พื้นที่เก็บข้อมูล รหัส \"%i\" ไม่อนุญาตให้ผู้ใช้แก้ไขข้อมูลได้",
    "Access key" : "คีย์การเข้าถึง",
    "Secret key" : "คีย์ลับ",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "ชื่อผู้เช่า",
    "Identity endpoint URL" : "ตัวตนของ URL ปลายทาง",
    "Rackspace" : "Rackspace",
    "API key" : "รหัส API",
    "RSA public key" : "RSA คีย์สาธารณะ",
    "Public key" : "คีย์สาธารณะ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "ชื่อโฮสต์",
    "Port" : "พอร์ต",
    "Region" : "พื้นที่",
    "Enable SSL" : "เปิดใช้งาน SSL",
    "Enable Path Style" : "เปิดใช้งานสไตล์เส้นทาง",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "โฟลเดอร์ย่อยรีโมท",
    "Secure https://" : "โหมดปลอดภัย https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "กูเกิ้ลไดร์ฟ",
    "Local" : "ต้นทาง",
    "Location" : "ตำแหน่งที่อยู่",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "โฮสต์",
    "Root" : "รูท",
    "SFTP with secret key login" : "SFTP กับคีย์ลับสำหรับเข้าสู่ระบบ",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "แชร์",
    "Domain" : "โดเมน",
    "SMB / CIFS using OC login" : "SMB/CIFS กำลังใช้ OC เข้าสู่ระบบ",
    "Username as share" : "ชื่อผู้ใช้ที่แชร์",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "ชื่อบริการ",
    "Request timeout (seconds)" : "หมดเวลาการร้องขอ (วินาที)",
    "<b>Note:</b> " : "<b>หมายเหตุ:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> การสนับสนุน cURL ใน PHP ไม่ได้เปิดใช้งานหรือติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> %s ไม่ได้ติดตั้ง การติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
    "No external storage configured" : "ไม่มีการกำหนดค่าจัดเก็บข้อมูลภายนอก",
    "You can add external storages in the storage settings" : "คุณสามารถเพิ่มการจัดเก็บข้อมูลภายนอกในการตั้งค่าพื้นที่เก็บข้อมูลได้",
    "Name" : "ชื่อ",
    "Storage type" : "ชนิดการจัดเก็บข้อมูล",
    "Scope" : "ขอบเขต",
    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
    "Enable previews" : "เปิดใช้งานการแสดงตัวอย่าง",
    "Enable sharing" : "เปิดให้สามารถแชร์ได้",
    "Check for changes" : "ตรวจสอบการเปลี่ยนแปลง",
    "Never" : "ไม่เคย",
    "Once every direct access" : "เมื่อทุกคนเข้าถึงโดยตรง",
    "External Storage" : "พื้นทีจัดเก็บข้อมูลจากภายนอก",
    "Enable external storage" : "เปิดการใช้งานพื้นที่จัดเก็บข้อมูลภายนอก",
    "External storage has been disabled by the administrator" : "ผู้ดูแลระบบได้ปิดการใช้งานการจัดเก็บข้อมูลภายนอก",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Authentication" : "รับรองความถูกต้อง",
    "Configuration" : "การกำหนดค่า",
    "Available for" : "สามารถใช้ได้สำหรับ",
    "Add storage" : "เพิ่มพื้นที่จัดเก็บข้อมูล",
    "Advanced settings" : "ตั้งค่าขั้นสูง",
    "Delete" : "ลบ",
    "Allow users to mount external storage" : "อนุญาตให้ผู้ใช้ติดตั้งการจัดเก็บข้อมูลภายนอก",
    "Allow users to mount the following external storage" : "อนุญาตให้ผู้ใช้ติดตั้งจัดเก็บข้อมูลภายนอกต่อไปนี้"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/files_external/l10n/th_TH.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "การเรียกร้องขอโทเคนล้มเหลว โปรดตรวจสอบคีย์และรหัสลับให้ถูกต้อง",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "การเรียกร้องขอโทเคนล้มเหลว โปรดตรวจสอบคีย์และรหัสลับของแอพฯ ให้ถูกต้อง",
    "Please provide a valid app key and secret." : "โปรดระบุคีย์และรหัสลับของแอพฯ ให้ถูกต้อง",
    "Step 1 failed. Exception: %s" : "ขั้นตอนที่ 1 ล้มเหลว ข้อยกเว้น: %s",
    "Step 2 failed. Exception: %s" : "ขั้นตอนที่ 2 ล้มเหลว ข้อยกเว้น: %s",
    "External storage" : "จัดเก็บข้อมูลภายนอก",
    "Dropbox App Configuration" : "ตั้งค่าแอพฯ Dropbox",
    "Google Drive App Configuration" : "ตั้งค่าแอพฯ Google Drive",
    "Personal" : "ส่วนตัว",
    "System" : "ระบบ",
    "Grant access" : "อนุญาตให้เข้าถึงได้",
    "Error configuring OAuth1" : "ข้อผิดพลาดในการกำหนดค่า OAuth1",
    "Error configuring OAuth2" : "ข้อผิดพลาดในการกำหนดค่า OAuth2",
    "Generate keys" : "สร้างคีย์",
    "Error generating key pair" : "ข้อผิดพลาดในการสร้างคีย์แบบเป็นคู่",
    "All users. Type to select user or group." : "ผู้ใช้ทุกคน พิมพ์เพื่อเลือกผู้ใช้หรือกลุ่ม",
    "(group)" : "(กลุ่ม)",
    "Compatibility with Mac NFD encoding (slow)" : "ความเข้ากันได้กับการเข้ารหัส Mac NFS (ช้า)",
    "Admin defined" : "ถูกกำหนดโดยผู้ดูแลระบบ",
    "Saved" : "บันทึกแล้ว",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "หากปิดการใช้งานการจัดเก็บข้อมูลภายนอก ข้อมูลของผู้ใช้ทั้งหมดจะถูกยกเลิกการต่อเชื่อม คุณแน่ใจ?",
    "Disable external storage" : "ปิดการใช้งานพื้นที่จัดเก็บข้อมูลภายนอก",
    "Empty response from the server" : "ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
    "Couldn't access. Please logout and login to activate this mount point" : "ไม่สามารถเข้าถึง กรุณออกจากระบบและาเข้าสู่ระบบใหม่เพื่อเปิดใช้งานจุดเชื่อมต่อนี้",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "ไม่สามารถรับข้อมูลจากเซิร์ฟเวอร์ ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "ไม่สามารถรับรายชื่อของจุดเชื่อมต่อภายนอก: {type}",
    "There was an error with message: " : "มีข้อความแสดงข้อผิดพลาด",
    "External mount error" : "การติดจากตั้งภายนอกเกิดข้อผิดพลาด",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "ไม่สามารถรับรายชื่อไดรฟ์เครือข่ายของวินโดว์ส จุดที่ติดตั้ง: ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "การกำหนดค่าบางส่วนของจุดเชื่อมต่อภายนอกไม่ถูกเชื่อมต่อ กรุณาคลิกที่ตรงสีแดงสำหรับข้อมูลเพิ่มเติม",
    "Please enter the credentials for the {mount} mount" : "กรุณากรอกข้อมูลประจำตัวสำหรับ {mount} ",
    "Username" : "ชื่อผู้ใช้งาน",
    "Password" : "รหัสผ่าน",
    "Credentials saved" : "ข้อมูลประจำตัวได้ถูกบันทึก",
    "Credentials saving failed" : "บันทึกข้อมูลประจำตัวล้มเหลว",
    "Credentials required" : "จำเป็นต้องระบบข้อมูลประจำตัว",
    "Save" : "บันทึก",
    "Storage with id \"%i\" not found" : "ไม่พบจัดการเก็บข้อมูลของ ID \"%i\"",
    "Invalid backend or authentication mechanism class" : "แบ็กเอนด์ไม่ถูกต้องหรือระดับการรับรองความถูกต้องไม่เพียงพอ",
    "Invalid mount point" : "จุดเชื่อมต่อที่ไม่ถูกต้อง",
    "Objectstore forbidden" : "เก็บวัตถุต้องห้าม",
    "Invalid storage backend \"%s\"" : "การจัดเก็บข้อมูลแบ็กเอนด์ไม่ถูกต้อง \"%s\"",
    "Not permitted to use backend \"%s\"" : "ไม่อนุญาตให้ใช้แบ็กเอนด์ \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "ไม่อนุญาตให้ตรวจสอบการรับรองความถูกต้อง \"%s\"",
    "Unsatisfied backend parameters" : "พารามิเตอร์แบ็กเอนด์ไม่ได้รับอนุญาต",
    "Unsatisfied authentication mechanism parameters" : "การรับรองความถูกต้องไม่เพียงพอ",
    "Insufficient data: %s" : "ข้อมูลไม่เพียงพอ: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "พื้นที่เก็บข้อมูล รหัส \"%i\" ไม่อนุญาตให้ผู้ใช้แก้ไขข้อมูลได้",
    "Access key" : "คีย์การเข้าถึง",
    "Secret key" : "คีย์ลับ",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "ชื่อผู้เช่า",
    "Identity endpoint URL" : "ตัวตนของ URL ปลายทาง",
    "Rackspace" : "Rackspace",
    "API key" : "รหัส API",
    "RSA public key" : "RSA คีย์สาธารณะ",
    "Public key" : "คีย์สาธารณะ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "ชื่อโฮสต์",
    "Port" : "พอร์ต",
    "Region" : "พื้นที่",
    "Enable SSL" : "เปิดใช้งาน SSL",
    "Enable Path Style" : "เปิดใช้งานสไตล์เส้นทาง",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "โฟลเดอร์ย่อยรีโมท",
    "Secure https://" : "โหมดปลอดภัย https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "กูเกิ้ลไดร์ฟ",
    "Local" : "ต้นทาง",
    "Location" : "ตำแหน่งที่อยู่",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "โฮสต์",
    "Root" : "รูท",
    "SFTP with secret key login" : "SFTP กับคีย์ลับสำหรับเข้าสู่ระบบ",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "แชร์",
    "Domain" : "โดเมน",
    "SMB / CIFS using OC login" : "SMB/CIFS กำลังใช้ OC เข้าสู่ระบบ",
    "Username as share" : "ชื่อผู้ใช้ที่แชร์",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "ชื่อบริการ",
    "Request timeout (seconds)" : "หมดเวลาการร้องขอ (วินาที)",
    "<b>Note:</b> " : "<b>หมายเหตุ:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> การสนับสนุน cURL ใน PHP ไม่ได้เปิดใช้งานหรือติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> %s ไม่ได้ติดตั้ง การติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
    "No external storage configured" : "ไม่มีการกำหนดค่าจัดเก็บข้อมูลภายนอก",
    "You can add external storages in the storage settings" : "คุณสามารถเพิ่มการจัดเก็บข้อมูลภายนอกในการตั้งค่าพื้นที่เก็บข้อมูลได้",
    "Name" : "ชื่อ",
    "Storage type" : "ชนิดการจัดเก็บข้อมูล",
    "Scope" : "ขอบเขต",
    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
    "Enable previews" : "เปิดใช้งานการแสดงตัวอย่าง",
    "Enable sharing" : "เปิดให้สามารถแชร์ได้",
    "Check for changes" : "ตรวจสอบการเปลี่ยนแปลง",
    "Never" : "ไม่เคย",
    "Once every direct access" : "เมื่อทุกคนเข้าถึงโดยตรง",
    "External Storage" : "พื้นทีจัดเก็บข้อมูลจากภายนอก",
    "Enable external storage" : "เปิดการใช้งานพื้นที่จัดเก็บข้อมูลภายนอก",
    "External storage has been disabled by the administrator" : "ผู้ดูแลระบบได้ปิดการใช้งานการจัดเก็บข้อมูลภายนอก",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Authentication" : "รับรองความถูกต้อง",
    "Configuration" : "การกำหนดค่า",
    "Available for" : "สามารถใช้ได้สำหรับ",
    "Add storage" : "เพิ่มพื้นที่จัดเก็บข้อมูล",
    "Advanced settings" : "ตั้งค่าขั้นสูง",
    "Delete" : "ลบ",
    "Allow users to mount external storage" : "อนุญาตให้ผู้ใช้ติดตั้งการจัดเก็บข้อมูลภายนอก",
    "Allow users to mount the following external storage" : "อนุญาตให้ผู้ใช้ติดตั้งจัดเก็บข้อมูลภายนอกต่อไปนี้",
    "No URL provided by backend " : "ไม่มี URL ที่มาจากแบ็กเอนด์",
    "Please make sure that the app that provides this backend is installed and enabled" : "โปรดตรวจสอบว่ามีการติดตั้งและเปิดใช้แอพฯสำหรับแบ็กเอนด์นี้แล้ว",
    "Allow sharing on user-mounted external storages" : "อนุญาตให้แชร์การจัดเก็บข้อมูลภายนอกของผู้ใช้",
    "Error getting OAuth2 URL for " : "เกิดข้อผิดพลาดในการรับ URL OAuth2 สำหรับ"
},
"nplurals=1; plural=0;");
